@@ -21,7 +21,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: Test.pm,v 1.14 2007/12/08 17:35:16 danpb Exp $
+# $Id: Test.pm,v 1.15 2007/12/10 03:16:16 danpb Exp $
 
 =pod
 
@@ -91,7 +91,7 @@ sub process {
 	$controlfile = "autotest.sh" unless defined $controlfile;
 
 	if ($module->build_status() ne 'success' &&
-	    $module->build_status() ne 'cache') {
+	    $module->build_status() ne 'cached') {
 	    $log->info("skipping " . $module->name);
 	    next;
 	}
